import neo4j from 'neo4j-driver';

const uri = 'bolt://localhost:7687'; // Stelle sicher, dass dies korrekt ist
const user = 'neo4j';
const password = 'sml12345';

const driver = neo4j.driver(uri, neo4j.auth.basic(user, password));



export const runQuery = async (query, params) => {
    const session = driver.session({ database: 'neo4j' });

    try {
        const result = await session.run(query, params);
        return result;
    } catch (error) {
        console.error('Neo4j Fehler:', error);
        throw new Error('Verbindungsproblem mit Neo4j.');
    } finally {
        await session.close(); // Verhindert offene Sessions
    }
};

// Hilfsfunktion zum Verwalten von Fehlern und Verbindungsproblemen
const handleError = (error) => {
    console.error('Neo4j Error:', error);
    throw new Error('Es gab ein Problem mit der Datenbankverbindung. Bitte versuche es später erneut.');
};

export const getEverything = async () => {
    const query = `MATCH (n) RETURN n`;
    return await runQuery(query);
}

// Erstelle einen Benutzer
export const createUser = async (id, name, email, location) => {
    const query = `CREATE (u:User {id: $id, name: $name, email: $email, location: $location}) RETURN u`;
    return await runQuery(query, { id, name, email, location });
};

// Erstelle eine Firma
export const createCompany = async (id, name) => {
    const query = `CREATE (c:Company {id: $id, name: $name}) RETURN c`;
    return await runQuery(query, { id, name });
};

// Erstelle einen Job
export const createJob = async (id, title, location) => {
    const query = `CREATE (j:Job {id: $id, title: $title, location: $location}) RETURN j`;
    return await runQuery(query, { id, title, location });
};

// Update Benutzer
export const updateUser = async (id, email, location) => {
    const query = `MATCH (u:User {id: $id}) SET u.email = $email, u.location = $location RETURN u`;
    return await runQuery(query, { id, email, location });
};

// Update Firma
export const updateCompany = async (id, name, industry) => {
    const query = `MATCH (c:Company {id: $id}) SET c.name = $name, c.industry = $industry RETURN c`;
    return await runQuery(query, { id, name, industry });
};

// Update Job
export const updateJob = async (id, title, location) => {
    const query = `MATCH (j:Job {id: $id}) SET j.title = $title, j.location = $location RETURN j`;
    return await runQuery(query, { id, title, location });
};

// Lösche Benutzer
export const deleteUser = async (id) => {
    const query = `MATCH (u:User {id: $id}) DETACH DELETE u`;
    return await runQuery(query, { id });
};

// Lösche Firma
export const deleteCompany = async (id) => {
    const query = `MATCH (c:Company {id: $id}) DETACH DELETE c`;
    return await runQuery(query, { id });
};

// Lösche Job
export const deleteJob = async (id) => {
    const query = `MATCH (j:Job {id: $id}) DETACH DELETE j`;
    return await runQuery(query, { id });
};

// Hole Benutzer nach Name
export const getUser = async (name) => {
    const query = `MATCH (u:User {name: $name}) RETURN u`;
    return await runQuery(query, { name });
};

// Hole alle Benutzer
export const getAllUsers = async () => {
    const query = `MATCH (u:User) RETURN u`;
    return await runQuery(query);
};

// Hole Benutzerbeziehungen
export const getUserRelationships = async (name) => {
    const query = `MATCH (u:User {name: $name})-[r]-() RETURN r`;

    if (!name) {
        console.error("Fehlender Parameter: name");
        throw new Error("Parameter 'name' ist erforderlich");
    }

    try {
        const result = await runQuery(query, { name });
        console.log(result.records); // Log query output
        return result;
    } catch (error) {
        console.error('Query failed:', error);
        throw error;
    }
};

// Hole die Firma, in der der Benutzer arbeitet
export const getUserCompany = async (name) => {
    const query = `MATCH (u:User {name: $name})-[:WORKS_FOR]->(c:Company) RETURN c`;
    return await runQuery(query, { name });
};

// Hole Remote Jobs
export const getRemoteJobs = async () => {
    const query = `MATCH (j:Job) WHERE j.location = 'Remote' RETURN j`;
    return await runQuery(query);
};

export const createFollowsRelationship = async (userId1, userId2) => {
    const query = `
        MATCH (u1:User {id: $userId1}), (u2:User {id: $userId2})
        MERGE (u1)-[:FOLLOWS]->(u2)
        RETURN u1, u2
    `;
    return await runQuery(query, { userId1, userId2 });
};