import {createFollowsRelationship, getAllUsers, getUserRelationships, runQuery} from "../lib/db";
import {BrowserRouter as Router, Routes, Route, Link, useNavigate} from "react-router-dom";
import React, {useEffect, useState} from "react";


export default function Home() {
    const [users, setUsers] = useState([]);
    const [follows, setFollows] = useState([]);
    const [user, setUser] = useState({});

    useEffect(() => {
        const fetchUsers = async () => {
            const storedUser = JSON.parse(sessionStorage.getItem("user"));
            if (!storedUser) return;

            setUser(storedUser);
            const name = storedUser.name;

            const usersData = await getAllUsers();
            const relData = await getUserRelationships(name);

            const randomUsers = usersData.records.sort(() => 0.5 - Math.random()).slice(0, 10);
            setUsers(randomUsers.map(record => record.get('u').properties));

            // Extrahiere sicher die gefolgten Benutzer-IDs, falls 'end' existiert
            const followedUserIds = relData.records
                .map(record => record.get('r').end?.properties?.id)
                .filter(id => id); // Entfernt `undefined`-Werte
            setFollows(followedUserIds);
        };

        fetchUsers();
    }, []);

    const folgen = async (toFollowId) => {
        if (!user.id) return; // Falls `user` nicht geladen ist, abbrechen

        await createFollowsRelationship(user.id, toFollowId);

        // Nach erfolgreichem Folgen die Liste aktualisieren
        const relData = await getUserRelationships(user.name);
        const followedUserIds = relData.records
            .map(record => record.get('r').end?.properties?.id)
            .filter(id => id);
        setFollows(followedUserIds);
        console.log(followedUserIds);
    };

    return (
        <div className="Profile">
            <h2>Empfohlene Benutzer</h2>
            <ul>
                {users.map((usr) => (
                    <li key={usr.id}>
                        {Object.entries(usr).map(([key, value]) => (
                            <p key={key}><strong>{key}:</strong> {String(value)}</p>
                        ))}
                        <button
                            onClick={() => folgen(usr.id)}
                            disabled={follows.includes(usr.id)}
                        >
                            {follows.includes(usr.id) ? "Bereits gefolgt" : "Folgen"}
                        </button>
                    </li>
                ))}
            </ul>
        </div>
    );
}