import React, { useEffect, useState } from 'react';
import { getUser, updateUser, deleteUser } from '../lib/db';
import { useNavigate } from 'react-router-dom';
import '../css/Profile.css';

export default function Profile() {
    const [user, setUser] = useState({});
    const [email, setEmail] = useState('');
    const [location, setLocation] = useState('');
    const [isEditing, setIsEditing] = useState(false);
    const navigate = useNavigate();

    useEffect(() => {
        const fetchUser = async () => {
            try {
                const name = JSON.parse(sessionStorage.getItem("user"))?.name;
                if (!name) throw new Error("Kein Benutzer gefunden.");

                const result = await getUser(name);
                if (result.records.length === 0) throw new Error("Benutzer nicht gefunden.");

                const userData = result.records[0].get('u').properties;
                setUser(userData);
                setEmail(userData.email);
                setLocation(userData.location);
            } catch (error) {
                console.error("Fehler beim Laden des Benutzers:", error);
            }
        };
        fetchUser();
    }, []);

    // Benutzer aktualisieren
    const handleUpdate = async () => {
        try {
            await updateUser(user.id, email, location);
            setUser({ ...user, email, location });
            setIsEditing(false);
        } catch (error) {
            console.error("Fehler beim Aktualisieren:", error);
        }
    };

    // Benutzer löschen
    const handleDelete = async () => {
        try {
            await deleteUser(user.id);
            sessionStorage.removeItem("user");
            navigate('/');
        } catch (error) {
            console.error("Fehler beim Löschen:", error);
        }
    };

    return (
        <div className="user-container">
            <h1>Profil</h1>
            {!isEditing ? (
                <>
                    <h2>{user.name}</h2>
                    <p>E-Mail: {user.email}</p>
                    <p>Standort: {user.location}</p>
                    <button onClick={() => setIsEditing(true)}>Bearbeiten</button>
                    <button onClick={handleDelete} style={{ background: 'red', color: 'white' }}>Löschen</button>
                </>
            ) : (
                <>
                    <input type="email" value={email} onChange={(e) => setEmail(e.target.value)} />
                    <input type="text" value={location} onChange={(e) => setLocation(e.target.value)} />
                    <button onClick={handleUpdate}>Speichern</button>
                    <button onClick={() => setIsEditing(false)}>Abbrechen</button>
                </>
            )}
        </div>
    );
}
